@@ -207,9 +207,19 @@ C       Output:  GA --- Г(x)
 C       ==================================================
 C
         IMPLICIT DOUBLE PRECISION (A-H,O-Z)
-        DIMENSION G(26)
-        PI=3.141592653589793D0
-        IF (X.EQ.INT(X)) THEN
+       DIMENSION G(26)
+       PARAMETER (PI=3.141592653589793D0)
+       DATA G/1.0D0,0.5772156649015329D0, -0.6558780715202538D0,
+     &          -0.420026350340952D-1, 0.1665386113822915D0,
+     &          -.421977345555443D-1, -.96219715278770D-2,
+     &          .72189432466630D-2, -.11651675918591D-2, 
+     &          -.2152416741149D-3, .1280502823882D-3, 
+     &          -.201348547807D-4, -.12504934821D-5, 
+     &          .11330272320D-5, -.2056338417D-6, .61160950D-8, 
+     &          .50020075D-8, -.11812746D-8, .1043427D-9, 
+     &          .77823D-11, -.36968D-11, .51D-12, 
+     &          -.206D-13, -.54D-14, .14D-14, .1D-15/     
+       IF (X.EQ.INT(X)) THEN
            IF (X.GT.0.0D0) THEN
               GA=1.0D0
               M1=INT(X-1)
@@ -231,18 +241,7 @@ C
            ELSE
               Z=X
            ENDIF
-           DATA G/1.0D0,0.5772156649015329D0,
-     &          -0.6558780715202538D0, -0.420026350340952D-1,
-     &          0.1665386113822915D0,-.421977345555443D-1,
-     &          -.96219715278770D-2, .72189432466630D-2,
-     &          -.11651675918591D-2, -.2152416741149D-3,
-     &          .1280502823882D-3, -.201348547807D-4,
-     &          -.12504934821D-5, .11330272320D-5,
-     &          -.2056338417D-6, .61160950D-8,
-     &          .50020075D-8, -.11812746D-8,
-     &          .1043427D-9, .77823D-11,
-     &          -.36968D-11, .51D-12,
-     &          -.206D-13, -.54D-14, .14D-14, .1D-15/
+
            GR=G(26)
            DO 20 K=25,1,-1
             GR=GR*Z+G(K)
@@ -348,7 +347,7 @@ C       Routine called: CGAMA for computing complex ln[Г(x)]
 C       ===================================================
 C
         IMPLICIT DOUBLE PRECISION (A-B,D-H,O-Z)
-        IMPLICIT COMPLEX*16 (C)
+        IMPLICIT COMPLEX(KIND=KIND(0.0D0)) (C)
         PI=3.141592653589793D0
         A0=A
         A1=A
@@ -449,7 +448,7 @@ C       Routine called: CGAMA for computing complex ln[Г(x)]
 C       ===================================================
 C
         IMPLICIT DOUBLE PRECISION (A,B,D-H,O-Y)
-        IMPLICIT COMPLEX *16 (C,Z)
+        IMPLICIT COMPLEX(KIND=KIND(0.0D0)) (C,Z)
         PI=3.141592653589793D0
         CI=(0.0D0,1.0D0)
         A0=A
@@ -577,7 +576,7 @@ C       ========================================================
 C
         IMPLICIT DOUBLE PRECISION (A-H,O-Z)
         DIMENSION A(10)
-        PI=3.141592653589793D0
+        PARAMETER (PI=3.141592653589793D0)
         DATA A/8.333333333333333D-02,-2.777777777777778D-03,
      &         7.936507936507937D-04,-5.952380952380952D-04,
      &         8.417508417508418D-04,-1.917526917526918D-03,
